@@ -1,7 +1,7 @@
 """Tests for the views of the ``document_library`` app."""
 from django.test import TestCase, RequestFactory
 
-from .factories import DocumentTitleENFactory
+from .factories import DocumentFactory
 from document_library.views import DocumentDetailView, DocumentListView
 
 
@@ -16,7 +16,7 @@ class DocumentListViewTestCase(TestCase):
 class DocumentDetailViewTestCase(TestCase):
     """Tests for the ``DocumentDetailView`` view."""
     def test_view(self):
-        doc_title = DocumentTitleENFactory()
+        doc = DocumentFactory()
         req = RequestFactory().get('/')
-        resp = DocumentDetailView.as_view()(req, pk=doc_title.pk)
+        resp = DocumentDetailView.as_view()(req, pk=doc.pk)
         self.assertEqual(resp.status_code, 200)
